@@ -2,6 +2,7 @@
 """
 import json
 import re
+from typing import List, Any
 
 from core_explore_example_app.commons.exceptions import MongoQueryException
 from core_explore_example_app.components.saved_query import api as saved_query_api
@@ -17,7 +18,11 @@ from core_parser_app.components.data_structure_element import (
     api as data_structure_element_api,
 )
 from xml_utils.xsd_tree.operations.namespaces import get_namespaces, get_default_prefix
-from xml_utils.xsd_types.xsd_types import get_xsd_numbers, get_xsd_floating_numbers
+from xml_utils.xsd_types.xsd_types import (
+    get_xsd_numbers,
+    get_xsd_floating_numbers,
+    get_xsd_gregorian_types,
+)
 
 
 def build_query_criteria(query, is_not=False):
@@ -99,56 +104,59 @@ def build_string_criteria(path, comparison, value):
     return criteria
 
 
-def build_and_criteria(criteria1, criteria2):
-    """Builds a criteria that is the result of criteria1 and criteria2
+def build_and_criteria(*criteria_list):
+    """Builds a criteria that is the result of and operator for N criteria
 
     Args:
-        criteria1:
-        criteria2:
+        criteria_list:
 
     Returns:
 
     """
     and_criteria = dict()
     and_criteria["$and"] = []
-    and_criteria["$and"].append(criteria1)
-    and_criteria["$and"].append(criteria2)
+
+    for criteria in criteria_list:
+        and_criteria["$and"].append(criteria)
+
     return and_criteria
 
 
-def build_or_criteria(criteria1, criteria2):
-    """Builds a criteria that is the result of criteria1 or criteria2
+def build_or_criteria(*criteria_list):
+    """Builds a criteria that is the result of or operator for N criteria
 
     Args:
-        criteria1:
-        criteria2:
+        criteria_list:
 
     Returns:
 
     """
     or_criteria = dict()
     or_criteria["$or"] = []
-    or_criteria["$or"].append(criteria1)
-    or_criteria["$or"].append(criteria2)
+
+    for criteria in criteria_list:
+        or_criteria["$or"].append(criteria)
+
     return or_criteria
 
 
-def build_wildcard_elem_match_criteria(criteria1, criteria2):
+def build_wildcard_elem_match_criteria(*criteria_list):
     # FIXME: Wildcard method should be move to the example type app
     # FIXME: Mongo_query could be an util class and be inherited as needed
-    """Builds a criteria that is the result of criteria1 elemMatch criteria2
+    """Builds a criteria that is the result of N criteria elemMatch
 
     Args:
-        criteria1:
-        criteria2:
+        criteria_list:
 
     Returns:
 
     """
     elem_match_criteria = dict()
     elem_match_criteria["$elemMatch"] = {}
-    elem_match_criteria["$elemMatch"].update(criteria1)
-    elem_match_criteria["$elemMatch"].update(criteria2)
+
+    for criteria in criteria_list:
+        elem_match_criteria["$elemMatch"].update(criteria)
+
     return {"list_content": elem_match_criteria}
 
 
@@ -192,29 +200,50 @@ def build_criteria(
     Returns:
 
     """
+    element_query: List[Any] = []
+    attribute_query: List[Any] = []
     # build the query: value can be found at element:value or at element.#text:value
     # second case appends when the element has attributes or namespace information
     if element_type in get_xsd_numbers(default_prefix):
-        element_query = build_int_criteria(element_path, comparison, value)
-        attribute_query = build_int_criteria(
-            "{}.#text".format(element_path), comparison, value
+        element_query.append(build_int_criteria(element_path, comparison, value))
+        attribute_query.append(
+            build_int_criteria("{}.#text".format(element_path), comparison, value)
         )
     elif element_type in get_xsd_floating_numbers(default_prefix):
-        element_query = build_float_criteria(element_path, comparison, value)
-        attribute_query = build_float_criteria(
-            "{}.#text".format(element_path), comparison, value
+        element_query.append(build_float_criteria(element_path, comparison, value))
+        attribute_query.append(
+            build_float_criteria("{}.#text".format(element_path), comparison, value)
         )
+    elif element_type in get_xsd_gregorian_types(default_prefix):
+        # before creating the int query check if the value type is int
+        try:
+            int_value = int(value)
+            # if the format is number perform a strict match
+            attribute_query.append(
+                build_int_criteria("{}.#text".format(element_path), "=", int_value)
+            )
+            element_query.append(build_int_criteria(element_path, "=", int_value))
+        except Exception:
+            pass
+
+        # string query
+        element_query.append(build_string_criteria(element_path, comparison, value))
+        attribute_query.append(
+            build_string_criteria("{}.#text".format(element_path), comparison, value)
+        )
+
     else:
-        element_query = build_string_criteria(element_path, comparison, value)
-        attribute_query = build_string_criteria(
-            "{}.#text".format(element_path), comparison, value
+        element_query.append(build_string_criteria(element_path, comparison, value))
+        attribute_query.append(
+            build_string_criteria("{}.#text".format(element_path), comparison, value)
         )
 
     if use_wildcard:
-        element_query = build_wildcard_criteria(element_query)
-        attribute_query = build_wildcard_criteria(attribute_query)
+        element_query.append(build_wildcard_criteria(element_query))
+        attribute_query.append(build_wildcard_criteria(attribute_query))
 
-    criteria = build_or_criteria(element_query, attribute_query)
+    # add a $or operator
+    criteria = build_or_criteria(*(element_query + attribute_query))
 
     if is_not:
         return invert_query(criteria)
@@ -308,19 +337,20 @@ def get_dot_notation_to_element(data_structure_element, namespaces):
     return dot_notation
 
 
-def get_parent_name(data_structure_element_id, namespaces):
+def get_parent_name(data_structure_element_id, namespaces, request):
     """
 
     Args:
         data_structure_element_id:
         namespaces:
+        request:
 
     Returns:
 
     """
     # get the data structure element
     data_structure_element = data_structure_element_api.get_by_id(
-        data_structure_element_id
+        data_structure_element_id, request
     )
     # convert xml path to mongo dot notation
     data_structure_element_dot_notation = get_dot_notation_to_element(
@@ -332,19 +362,20 @@ def get_parent_name(data_structure_element_id, namespaces):
     return parent_name
 
 
-def get_parent_path(data_structure_element_id, namespaces):
+def get_parent_path(data_structure_element_id, namespaces, request):
     """
 
     Args:
         data_structure_element_id:
         namespaces:
+        request:
 
     Returns:
 
     """
     # get the data structure element
     data_structure_element = data_structure_element_api.get_by_id(
-        data_structure_element_id
+        data_structure_element_id, request
     )
     # convert xml path to mongo dot notation
     data_structure_element_dot_notation = get_dot_notation_to_element(
@@ -356,17 +387,18 @@ def get_parent_path(data_structure_element_id, namespaces):
     return parent_path
 
 
-def check_query_form(form_values, template_id):
+def check_query_form(form_values, template_id, request=None):
     """Checks that values entered by the user match each element type
 
     Args:
         form_values:
         template_id:
+        request:
 
     Returns:
 
     """
-    template = template_api.get(template_id)
+    template = template_api.get(template_id, request=request)
     namespaces = get_namespaces(template.content)
     default_prefix = get_default_prefix(namespaces)
 
@@ -391,57 +423,19 @@ def check_query_form(form_values, template_id):
     return errors
 
 
-def fields_to_query_custom_dot_notation(
-    form_values, template_id, get_dot_notation_to_element_func, use_wildcard=False
-):
-    """Takes values from the html tree and creates a query from them.
-    Can configure the get_dot_notation_to_element function to use.
-
-    Args:
-        form_values:
-        template_id:
-        use_wildcard:
-        get_dot_notation_to_element_func:
-
-    Returns:
-
-    """
-    return _fields_to_query(
-        form_values, template_id, get_dot_notation_to_element_func, use_wildcard
-    )
-
-
-def fields_to_query(form_values, template_id, use_wildcard=False):
+def fields_to_query(form_values, template_id, use_wildcard=False, request=None):
     """Takes values from the html tree and creates a query from them
 
     Args:
         form_values:
         template_id:
         use_wildcard:
-    Returns:
-
-    """
-    return _fields_to_query(
-        form_values, template_id, get_dot_notation_to_element, use_wildcard
-    )
-
-
-def _fields_to_query(
-    form_values, template_id, get_dot_notation_to_element_func, use_wildcard
-):
-    """Takes values from the html tree and creates a query from them
-
-    Args:
-        form_values:
-        template_id:
-        use_wildcard:
-        get_dot_notation_to_element_func:
-
+        request:
     Returns:
 
     """
     # get template
-    template = template_api.get(template_id)
+    template = template_api.get(template_id, request=request)
     # get namespaces
     namespaces = get_namespaces(template.content)
     # get default prefix
@@ -467,10 +461,10 @@ def _fields_to_query(
                 raise MongoQueryException("The saved query does not exist anymore.")
             criteria = build_query_criteria(json.loads(saved_query.query), is_not)
         else:
-            data_structure_element = data_structure_element_api.get_by_id(element_id)
-            element = get_dot_notation_to_element_func(
-                data_structure_element, namespaces
+            data_structure_element = data_structure_element_api.get_by_id(
+                element_id, request
             )
+            element = get_dot_notation_to_element(data_structure_element, namespaces)
             criteria = build_criteria(
                 element,
                 comparison,
@@ -494,13 +488,14 @@ def _fields_to_query(
     return query
 
 
-def sub_elements_to_query(form_values, namespaces, default_prefix):
+def sub_elements_to_query(form_values, namespaces, default_prefix, request):
     """Transforms HTML fields in a query on sub-elements
 
     Args:
         form_values:
         namespaces:
         default_prefix:
+        request:
 
     Returns:
 
@@ -508,7 +503,7 @@ def sub_elements_to_query(form_values, namespaces, default_prefix):
     elem_match = []
 
     # get the parent path using the first element of the list
-    parent_path = get_parent_path(form_values[0]["id"], namespaces)
+    parent_path = get_parent_path(form_values[0]["id"], namespaces, request)
 
     for i in range(0, len(form_values)):
         field = form_values[i]
@@ -519,7 +514,9 @@ def sub_elements_to_query(form_values, namespaces, default_prefix):
             else:
                 is_not = False
 
-            data_structure_element = data_structure_element_api.get_by_id(field["id"])
+            data_structure_element = data_structure_element_api.get_by_id(
+                field["id"], request
+            )
             element_type = data_structure_element.options["type"]
             element_name = data_structure_element.options["name"]
             value = get_element_value(field)
