@@ -10,10 +10,11 @@ from core_parser_app.components.data_structure_element import (
 from core_parser_app.tools.parser.parser import XSDParser, remove_child_element
 
 
-# TODO: the form renders 'add' buttons based on maxOccurs attributes, but we don't need more than one of each element
+# TODO: the form renders 'add' buttons based on maxOccurs attributes, but we
+#  don't need more than one of each element
 
 
-def get_parser():
+def get_parser(request=None):
     """Returns parser
 
     Returns:
@@ -28,25 +29,29 @@ def get_parser():
         implicit_extension_base=False,
         download_dependencies=PARSER_DOWNLOAD_DEPENDENCIES,
         store_type=True,
+        request=request,
     )
 
 
 # FIXME: refactor common code with core curate app (note: no xml_string here)
-def generate_form(xsd_string):
+def generate_form(xsd_string, request=None):
     """Generates the form using the parser, returns the root element
 
     Args:
         xsd_string:
+        request:
 
     Returns:
 
     """
     # build parser
-    parser = get_parser()
+    parser = get_parser(request=request)
     # generate form
-    root_element_id = parser.generate_form(xsd_string)
+    root_element_id = parser.generate_form(xsd_string, request=request)
     # get the root element
-    root_element = data_structure_element_api.get_by_id(root_element_id)
+    root_element = data_structure_element_api.get_by_id(
+        root_element_id, request=request
+    )
 
     return root_element
 
@@ -80,9 +85,9 @@ def generate_element_absent(request, element_id, xsd_string):
     Returns:
 
     """
-    xsd_parser = get_parser()
+    xsd_parser = get_parser(request=request)
     html_form = xsd_parser.generate_element_absent(
-        request, element_id, xsd_string, renderer_class=CustomCheckboxRenderer
+        element_id, xsd_string, renderer_class=CustomCheckboxRenderer
     )
     return html_form
 
@@ -98,9 +103,9 @@ def generate_choice_absent(request, element_id, xsd_string):
     Returns:
 
     """
-    xsd_parser = get_parser()
+    xsd_parser = get_parser(request=request)
     html_form = xsd_parser.generate_choice_absent(
-        request, element_id, xsd_string, renderer_class=CustomCheckboxRenderer
+        element_id, xsd_string, renderer_class=CustomCheckboxRenderer
     )
     return html_form
 
@@ -116,7 +121,7 @@ def remove_form_element(request, element_id):
     Returns:
 
     """
-    element_list = data_structure_element_api.get_all_by_child_id(element_id)
+    element_list = data_structure_element_api.get_all_by_child_id(element_id, request)
 
     if len(element_list) == 0:
         raise ValueError("No Data Structure Element found")
@@ -125,13 +130,15 @@ def remove_form_element(request, element_id):
 
     # Removing the element from the data structure
     data_structure_element = element_list[0]
-    data_structure_element_to_pull = data_structure_element_api.get_by_id(element_id)
+    data_structure_element_to_pull = data_structure_element_api.get_by_id(
+        element_id, request
+    )
 
     # number of children after deletion
     children_number = len(data_structure_element.children) - 1
 
     data_structure_element = remove_child_element(
-        data_structure_element, data_structure_element_to_pull
+        data_structure_element, data_structure_element_to_pull, request
     )
 
     code = 0
