@@ -1,10 +1,12 @@
 """Explore Example app Ajax views
 """
 import json
+import logging
 
 from django.http import HttpResponse
 from django.http.response import HttpResponseBadRequest
 from django.utils.decorators import method_decorator
+from django.utils.html import escape
 from django.views.generic import View
 
 import core_explore_example_app.permissions.rights as rights
@@ -52,6 +54,8 @@ from core_parser_app.components.data_structure_element import (
 from xml_utils.html_tree import parser as html_tree_parser
 from xml_utils.xsd_tree.operations.namespaces import get_namespaces, get_default_prefix
 
+logger = logging.getLogger(__name__)
+
 
 @decorators.permission_required(
     content_type=rights.explore_example_content_type,
@@ -73,11 +77,15 @@ def generate_element(request, explore_data_structure_id):
         explore_data_structure = explore_data_structure_api.get_by_id(
             explore_data_structure_id
         )
-        html_form = generate_element_absent(
-            request, element_id, explore_data_structure.template.content
+        template = template_api.get(
+            str(explore_data_structure.template.id), request=request
         )
+        html_form = generate_element_absent(request, element_id, template.content)
     except Exception as e:
-        return HttpResponseBadRequest()
+        return HttpResponseBadRequest(
+            "An unexpected error occurred: %s" % escape(str(e)),
+            content_type="application/javascript",
+        )
 
     return HttpResponse(html_form)
 
@@ -102,11 +110,15 @@ def generate_choice(request, explore_data_structure_id):
         explore_data_structure = explore_data_structure_api.get_by_id(
             explore_data_structure_id
         )
-        html_form = generate_choice_absent(
-            request, element_id, explore_data_structure.template.content
+        template = template_api.get(
+            str(explore_data_structure.template.id), request=request
         )
+        html_form = generate_choice_absent(request, element_id, template.content)
     except Exception as e:
-        return HttpResponseBadRequest()
+        return HttpResponseBadRequest(
+            "An unexpected error occurred: %s" % escape(str(e)),
+            content_type="application/javascript",
+        )
 
     return HttpResponse(html_form)
 
@@ -176,6 +188,7 @@ def save_fields(request):
 
         return HttpResponse(json.dumps({}), content_type="application/javascript")
     except Exception as e:
+        logger.error(escape(str(e)))
         return HttpResponseBadRequest("An error occurred while saving the form.")
 
 
@@ -197,7 +210,7 @@ def select_element(request):
     element_id = request.POST["elementID"]
 
     # get schema element
-    schema_element = data_structure_element_api.get_by_id(element_id)
+    schema_element = data_structure_element_api.get_by_id(element_id, request)
 
     response_dict = {
         "elementName": schema_element.options["label"],
@@ -230,7 +243,7 @@ def get_sub_elements_query_builder(request):
     list_leaves_id = leaves_id.split(" ")
 
     # get template
-    template = template_api.get(template_id)
+    template = template_api.get(template_id, request=request)
 
     # get template namespaces
     namespaces = get_namespaces(template.content)
@@ -238,11 +251,11 @@ def get_sub_elements_query_builder(request):
     default_prefix = get_default_prefix(namespaces)
 
     # get the parent name using the first schema element of the list
-    parent_name = get_parent_name(list_leaves_id[0], namespaces)
+    parent_name = get_parent_name(list_leaves_id[0], namespaces, request)
 
     form_fields = []
     for leaf_id in list_leaves_id:
-        data_structure_element = data_structure_element_api.get_by_id(leaf_id)
+        data_structure_element = data_structure_element_api.get_by_id(leaf_id, request)
         element_type = data_structure_element.options["type"]
         element_name = data_structure_element.options["name"]
 
@@ -286,7 +299,7 @@ def insert_sub_elements_query(request):
     criteria_id = request.POST["criteriaID"]
 
     # get template
-    template = template_api.get(template_id)
+    template = template_api.get(template_id, request=request)
 
     # get template namespaces
     namespaces = get_namespaces(template.content)
@@ -295,11 +308,11 @@ def insert_sub_elements_query(request):
 
     # keep only selected fields
     form_values = [field for field in form_values if field["selected"] is True]
-    errors = check_query_form(form_values, template_id)
+    errors = check_query_form(form_values, template_id, request=request)
 
     if len(errors) == 0:
-        query = sub_elements_to_query(form_values, namespaces, default_prefix)
-        displayed_query = sub_elements_to_pretty_query(form_values, namespaces)
+        query = sub_elements_to_query(form_values, namespaces, default_prefix, request)
+        displayed_query = sub_elements_to_pretty_query(form_values, namespaces, request)
         ui_id = "ui" + criteria_id[4:]
         temporary_query = SavedQuery(
             user_id=ExploreExampleAppConfig.name,
@@ -330,7 +343,8 @@ def insert_sub_elements_query(request):
     raise_exception=True,
 )
 def update_user_input(request):
-    """Updates the user input of the query builder according to the type of the selected element
+    """Updates the user input of the query builder according to the type of the
+    selected element
 
     Args:
         request:
@@ -342,9 +356,11 @@ def update_user_input(request):
     template_id = request.POST["templateID"]
 
     # get schema element
-    data_structure_element = data_structure_element_api.get_by_id(from_element_id)
+    data_structure_element = data_structure_element_api.get_by_id(
+        from_element_id, request
+    )
     # get template
-    template = template_api.get(template_id)
+    template = template_api.get(template_id, request=request)
 
     # convert xml path to mongo dot notation
     namespaces = get_namespaces(template.content)
@@ -525,13 +541,14 @@ class GetQueryView(View):
             order_by_field = request.POST["orderByField"].strip()
             order_by_field_array = order_by_field.split(";")
 
-            # save current query builder in session to restore it when coming back to the page
+            # save current query builder in session to restore it when coming
+            # back to the page
             if "queryForm" in request.POST:
                 query_form = request.POST["queryForm"]
                 request.session["savedQueryFormExplore"] = query_form
 
             errors = []
-            query_object = query_api.get_by_id(query_id)
+            query_object = query_api.get_by_id(query_id, request.user)
             # set the data-sources sorting value according to the POST request field
             for data_sources_index in range(len(query_object.data_sources)):
                 # updating only the existing data-sources (the new data-source already got
@@ -544,24 +561,29 @@ class GetQueryView(View):
                 errors.append("Please select at least 1 data source.")
 
             if len(errors) == 0 and form_values:
-                errors.append(check_query_form(form_values, template_id))
-                query_content = self.fields_to_query_func(form_values, template_id)
+                errors.append(
+                    check_query_form(form_values, template_id, request=request)
+                )
+                query_content = self.fields_to_query_func(
+                    form_values, template_id, request=request
+                )
                 query_object.content = json.dumps(query_content)
             elif len(errors) > 0:
                 return HttpResponseBadRequest(
                     _render_errors(errors), content_type="application/javascript"
                 )
 
-            query_api.upsert(query_object)
+            query_api.upsert(query_object, request.user)
 
             return HttpResponse(json.dumps({}), content_type="application/javascript")
         except exceptions.ModelError:
             return HttpResponseBadRequest(
                 "Invalid input.", content_type="application/javascript"
             )
-        except Exception:
+        except Exception as e:
             return HttpResponseBadRequest(
-                "An unexpected error occurred.", content_type="application/javascript"
+                "An unexpected error occurred: %s" % escape(str(e)),
+                content_type="application/javascript",
             )
 
 
@@ -593,16 +615,18 @@ class SaveQueryView(View):
             return HttpResponseBadRequest(error, content_type="application/javascript")
 
         # Check that the query is valid
-        errors = check_query_form(form_values, template_id)
+        errors = check_query_form(form_values, template_id, request=request)
         if len(errors) == 0:
             try:
-                query = self.fields_to_query_func(form_values, template_id)
+                query = self.fields_to_query_func(
+                    form_values, template_id, request=request
+                )
                 displayed_query = fields_to_pretty_query(form_values)
 
                 # save the query in the data base
                 saved_query = SavedQuery(
                     user_id=str(request.user.id),
-                    template=template_api.get(template_id),
+                    template=template_api.get(template_id, request=request),
                     query=json.dumps(query),
                     displayed_query=displayed_query,
                 )
