@@ -6,9 +6,7 @@ from django.urls import reverse_lazy, reverse
 from django.utils.decorators import method_decorator
 from django.views.generic import View
 
-import core_explore_example_app.components.persistent_query_example.api as persistent_query_example_api
 import core_explore_example_app.permissions.rights as rights
-import core_main_app.components.template_version_manager.api as template_version_manager_api
 import core_main_app.utils.decorators as decorators
 from core_explore_common_app.components.query import api as query_api
 from core_explore_common_app.settings import DEFAULT_DATE_TOGGLE_VALUE
@@ -20,11 +18,17 @@ from core_explore_common_app.views.user.views import (
 from core_explore_example_app.components.explore_data_structure import (
     api as explore_data_structure_api,
 )
+from core_explore_example_app.components.persistent_query_example import (
+    api as persistent_query_example_api,
+)
 from core_explore_example_app.components.saved_query import api as saved_query_api
 from core_explore_example_app.settings import INSTALLED_APPS
 from core_explore_example_app.utils.parser import render_form
 from core_main_app.commons import exceptions as exceptions
 from core_main_app.components.template import api as template_api
+from core_main_app.components.template_version_manager import (
+    api as template_version_manager_api,
+)
 from core_main_app.settings import DATA_SORTING_FIELDS
 from core_main_app.utils.rendering import render
 
@@ -54,8 +58,8 @@ class IndexView(View):
         """
         assets = {"css": ["core_explore_example_app/user/css/style.css"]}
 
-        global_active_template_list = self.get_global_active_list()
-        user_active_template_list = self.get_user_active_list(request.user.id)
+        global_active_template_list = self.get_global_active_list(request=request)
+        user_active_template_list = self.get_user_active_list(request=request)
 
         context = {
             "global_objects": global_active_template_list,
@@ -67,28 +71,29 @@ class IndexView(View):
 
         return render(request, self.get_redirect, assets=assets, context=context)
 
-    def get_global_active_list(self):
+    def get_global_active_list(self, request):
         """Get all global version managers.
 
         Args:
+            request:
 
         Returns:
             List of all global version managers
 
         """
-        return self.api.get_active_global_version_manager()
+        return self.api.get_active_global_version_manager(request=request)
 
-    def get_user_active_list(self, user_id):
+    def get_user_active_list(self, request):
         """Get all active version managers with given user id.
 
         Args:
-            user_id:
+            request:
 
         Returns:
             List of all global version managers with given user.
 
         """
-        return self.api.get_active_version_manager_by_user_id(user_id)
+        return self.api.get_active_version_manager_by_user_id(request=request)
 
 
 class SelectFieldsView(View):
@@ -152,11 +157,11 @@ class SelectFieldsView(View):
                 ],
             }
 
-            template = template_api.get(template_id)
+            template = template_api.get(template_id, request=request)
             # get data structure
             data_structure = (
                 explore_data_structure_api.create_and_get_explore_data_structure(
-                    template, request.user.id
+                    template, request
                 )
             )
             root_element = data_structure.data_structure_element_root
@@ -224,7 +229,7 @@ class BuildQueryView(View):
 
         """
         try:
-            template = template_api.get(template_id)
+            template = template_api.get(template_id, request=request)
             if template is None:
                 return render(
                     request,
@@ -262,7 +267,7 @@ class BuildQueryView(View):
                 # if not a new form and a query form is present in session
                 if "savedQueryFormExplore" in request.session:
                     saved_query_form = request.session["savedQueryFormExplore"]
-                query = query_api.get_by_id(query_id)
+                query = query_api.get_by_id(query_id, request.user)
 
             # Get saved queries of a user
             if "_auth_user_id" in request.session:
@@ -327,16 +332,16 @@ class BuildQueryView(View):
         """
         # from the template, we get the version manager
         template_version_manager = template_version_manager_api.get_by_version_id(
-            str(template.id)
+            str(template.id), request=request
         )
         # from the version manager, we get all the version
-        template_ids = template_api.get_all_by_id_list(
-            template_version_manager.versions
+        template_ids = template_api.get_all_accessible_by_id_list(
+            template_version_manager.versions, request=request
         )
         # create query
         query = create_default_query(request, template_ids)
         # then upsert
-        return query_api.upsert(query)
+        return query_api.upsert(query, request.user)
 
     @staticmethod
     def _get_js():
@@ -407,7 +412,7 @@ class ResultQueryView(ResultsView):
         """
 
         # get query
-        query = query_api.get_by_id(query_id)
+        query = query_api.get_by_id(query_id, request.user)
 
         context = {
             "template_id": template_id,
@@ -421,7 +426,7 @@ class ResultQueryView(ResultsView):
         }
 
         if "core_exporters_app" in INSTALLED_APPS:
-            query = query_api.get_by_id(query_id)
+            query = query_api.get_by_id(query_id, request.user)
 
             context["exporter_app"] = True
             context["templates_list"] = json.dumps(
@@ -471,9 +476,25 @@ class ResultQueryView(ResultsView):
 
 
 class ResultQueryExampleRedirectView(ResultQueryRedirectView):
+    @method_decorator(
+        decorators.permission_required(
+            content_type=rights.explore_example_content_type,
+            permission=rights.explore_example_access,
+            login_url=reverse_lazy("core_main_app_login"),
+        )
+    )
+    def get(self, request, *args, **kwargs):
+        return super(ResultQueryExampleRedirectView, self).get(
+            self, request, *args, **kwargs
+        )
+
     @staticmethod
-    def _get_persistent_query(persistent_query_id):
-        return persistent_query_example_api.get_by_id(persistent_query_id)
+    def _get_persistent_query_by_id(persistent_query_id, user):
+        return persistent_query_example_api.get_by_id(persistent_query_id, user)
+
+    @staticmethod
+    def _get_persistent_query_by_name(persistent_query_name, user):
+        return persistent_query_example_api.get_by_name(persistent_query_name, user)
 
     @staticmethod
     def _get_reversed_url(query):
